@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2005 by Joshua Keel <joshuakeel@gmail.com>              *
- *             (C) 2007-2014 by Jeremy Whiting <jpwhiting@kde.org>         *
+ *             (C) 2007-2021 by Jeremy Whiting <jpwhiting@kde.org>         *
  *             (C) 2012 by Laszlo Papp <lpapp@kde.org>                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -235,9 +235,6 @@ class KanagramGame : public QObject
         //Signal the UI that the word is broken into alphabets
         void userAnswerChanged();
 
-        //Signal for the UI to give the list of alphabets rather than the single string
-        void wordResult();
-
         /** Signal the ui that sound enabled has changed */
         void useSoundsChanged();
     private:
@@ -267,9 +264,6 @@ class KanagramGame : public QObject
         /** Load score settings into local variables */
         void loadSettings();
 
-        /** Random sequence used to scramble the letters */
-        KRandomSequence m_random;
-
         /** The current scrambled word */
         QString m_anagram;
 
